@@ -141,7 +141,6 @@ class Recipe(BaseSlapRecipe):
   def installCertificateAuthority(self, ca_country_code='XX',
       ca_email='xx@example.com', ca_state='State', ca_city='City',
       ca_company='Company'):
-    backup_path = self.createBackupDirectory('ca')
     self.ca_dir = os.path.join(self.data_root_directory, 'ca')
     self._createDirectory(self.ca_dir)
     self.ca_request_dir = os.path.join(self.ca_dir, 'requests')
@@ -182,15 +181,6 @@ class Recipe(BaseSlapRecipe):
           crl=os.path.join(self.ca_crl),
           request_dir=self.ca_request_dir
           )]))
-    # configure backup
-    backup_cron = os.path.join(self.cron_d, 'ca_rdiff_backup')
-    open(backup_cron, 'w').write(
-        '''0 0 * * * %(rdiff_backup)s %(source)s %(destination)s'''%dict(
-          rdiff_backup=self.options['rdiff_backup_binary'],
-          source=self.ca_dir,
-          destination=backup_path))
-    self.path_list.append(backup_cron)
-
     return dict(
       ca_certificate=os.path.join(config['ca_dir'], 'cacert.pem'),
       ca_crl=os.path.join(config['ca_dir'], 'crl'),
@@ -319,7 +309,7 @@ class Recipe(BaseSlapRecipe):
     mysql_backup_cron = os.path.join(self.cron_d, 'mysql_backup')
     with open(mysql_backup_cron, 'w') as file_:
       file_.write('0 0 * * * %(mysqldump)s | %(gzip)s > %(tmpdump)s' \
-                  '&& mv %(tmpdump)s %(dumpfile)s' % {
+                  '&& mv -f %(tmpdump)s %(dumpfile)s' % {
                     'mysqldump': mysqldump_cmdline_str,
                     'gzip': self.options['gzip_binary'],
                     'tmpdump': self.parseCmdArgument(tmpdump_file),
